/*******************************************************************************
* File Name: CLK_to_CP.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "CLK_to_CP.h"


/*******************************************************************************
* Function Name: CLK_to_CP_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void CLK_to_CP_Write(uint8 value) 
{
    uint8 staticBits = CLK_to_CP_DR & ~CLK_to_CP_MASK;
    CLK_to_CP_DR = staticBits | ((value << CLK_to_CP_SHIFT) & CLK_to_CP_MASK);
}


/*******************************************************************************
* Function Name: CLK_to_CP_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void CLK_to_CP_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(CLK_to_CP_0, mode);
}


/*******************************************************************************
* Function Name: CLK_to_CP_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro CLK_to_CP_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 CLK_to_CP_Read(void) 
{
    return (CLK_to_CP_PS & CLK_to_CP_MASK) >> CLK_to_CP_SHIFT;
}


/*******************************************************************************
* Function Name: CLK_to_CP_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 CLK_to_CP_ReadDataReg(void) 
{
    return (CLK_to_CP_DR & CLK_to_CP_MASK) >> CLK_to_CP_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(CLK_to_CP_INTSTAT) 

    /*******************************************************************************
    * Function Name: CLK_to_CP_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 CLK_to_CP_ClearInterrupt(void) 
    {
        return (CLK_to_CP_INTSTAT & CLK_to_CP_MASK) >> CLK_to_CP_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
