/*******************************************************************************
* File Name: NRQ_TEST.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "NRQ_TEST.h"


/*******************************************************************************
* Function Name: NRQ_TEST_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void NRQ_TEST_Write(uint8 value) 
{
    uint8 staticBits = NRQ_TEST_DR & ~NRQ_TEST_MASK;
    NRQ_TEST_DR = staticBits | ((value << NRQ_TEST_SHIFT) & NRQ_TEST_MASK);
}


/*******************************************************************************
* Function Name: NRQ_TEST_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void NRQ_TEST_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(NRQ_TEST_0, mode);
}


/*******************************************************************************
* Function Name: NRQ_TEST_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro NRQ_TEST_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 NRQ_TEST_Read(void) 
{
    return (NRQ_TEST_PS & NRQ_TEST_MASK) >> NRQ_TEST_SHIFT;
}


/*******************************************************************************
* Function Name: NRQ_TEST_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 NRQ_TEST_ReadDataReg(void) 
{
    return (NRQ_TEST_DR & NRQ_TEST_MASK) >> NRQ_TEST_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(NRQ_TEST_INTSTAT) 

    /*******************************************************************************
    * Function Name: NRQ_TEST_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 NRQ_TEST_ClearInterrupt(void) 
    {
        return (NRQ_TEST_INTSTAT & NRQ_TEST_MASK) >> NRQ_TEST_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
