/*******************************************************************************
* File Name: TC_to_SP.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "TC_to_SP.h"


/*******************************************************************************
* Function Name: TC_to_SP_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void TC_to_SP_Write(uint8 value) 
{
    uint8 staticBits = TC_to_SP_DR & ~TC_to_SP_MASK;
    TC_to_SP_DR = staticBits | ((value << TC_to_SP_SHIFT) & TC_to_SP_MASK);
}


/*******************************************************************************
* Function Name: TC_to_SP_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void TC_to_SP_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(TC_to_SP_0, mode);
}


/*******************************************************************************
* Function Name: TC_to_SP_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TC_to_SP_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TC_to_SP_Read(void) 
{
    return (TC_to_SP_PS & TC_to_SP_MASK) >> TC_to_SP_SHIFT;
}


/*******************************************************************************
* Function Name: TC_to_SP_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TC_to_SP_ReadDataReg(void) 
{
    return (TC_to_SP_DR & TC_to_SP_MASK) >> TC_to_SP_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TC_to_SP_INTSTAT) 

    /*******************************************************************************
    * Function Name: TC_to_SP_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TC_to_SP_ClearInterrupt(void) 
    {
        return (TC_to_SP_INTSTAT & TC_to_SP_MASK) >> TC_to_SP_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
