/*  --------------------------------------------------------------------------
* Copyright 2010, Cypress Semiconductor Corporation.
*
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international
* treaty provisions. Cypress hereby grants to licensee a personal,
* non-exclusive, non-transferable license to copy, use, modify, create
* derivative works of, and compile the Cypress Source Code and derivative
* works for the sole purpose of creating custom software in support of
* licensee product to be used only in conjunction with a Cypress integrated
* circuit as specified in the applicable agreement. Any reproduction,
* modification, translation, compilation, or representation of this
* software except as specified above is prohibited without the express
* written permission of Cypress.
* 
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED,
* WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising
* out of the application or use of any product or circuit described herein.
* Cypress does not authorize its products for use as critical components in
* life-support systems where a malfunction or failure may reasonably be
* expected to result in significant injury to the user. The inclusion of
* Cypress' product in a life-support systems application implies that the
* manufacturer assumes all risk of such use and in doing so indemnifies
* Cypress against all charges.
* 
* Use may be limited by and subject to the applicable Cypress software
* license agreement.
* -----------------------------------------------------------------------------
* Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
*
*****************************************************************************
*  Project Name: ADC_DMA_Memory_16Bit
*  Project Revision : 1.00
*  Software Version: PSoC Creator 1.0 SP2
*  Device Tested: CY8C3866AXI, CY8C5588AXI
*  Compilers Tested: Keil , ARM GCC
*  Related Hardware: CY8CKIT-001
*****************************************************************************
***************************************************************************** */

/* Project Description:
* This example project demonstrates how to buffer 16 bit ADC data using DMA.
* The DMA is configured to buffer specified number of ADC samples on a switch press. 
* The DMA channel is enabled on each switch press and disabled after collecting the specified number of ADC samples.
* Connect P1[2] to switch Sw1 on DVK and connect ADC input to P0[0]. 
* Run the debugger and Verify the output - Watch the 'ADC_sample1' buffer in watch window of debugger.
***************************************************************************** */

#include <device.h>
#include <math.h>
#define NO_OF_SAMPLES 1024     //#define VALID_SAMPLE  1000
#define W               25     //Screen width
#define data          2048
#define PI       3.1415926

/******************************************************************************
* Function Name: DmaDone
*******************************************************************************
*
* Summary:
*  Handle Interrupt Service Routine. Source - DMA.
*
******************************************************************************/
/*CY_ISR(DMA_1)
{
    DMADone_flag = 1;
}
*/

void main()
{
	uint16 ADC_sample1[NO_OF_SAMPLES]={0};
	uint16 ADC_sample2[NO_OF_SAMPLES]={0};
    uint16 Array1[1000]={0}, Array2[1000]={0};
	uint8  DMADone_flag1,DMADone_flag2,PWM_Stop_flag;
	uint8  X1,Y1,X2,Y2;
	uint16 loopCNT1,loopCNT2,i=0,j=0,VALID_SAMPLE1,VALID_SAMPLE2;
	uint16 target_data,target_data1,target_data2,target_data3;
	//uint16 No_of_Pulse1,No_of_Pulse2,No_of_Pulse3;
	float  S1=0,S2=0,M1=0,M2=0;
	//float  tan(float x);
	/* Variable declarations for DMA */
    uint8 DMA_1_Chan,DMA_2_Chan;
    uint8 DMA_1_TD[1],DMA_2_TD[1];
	   
    /* DMA Configuration for DMA */
    #define DMA_BYTES_PER_BURST 2
    #define DMA_REQUEST_PER_BURST 1
    #define DMA_SRC_BASE (CYDEV_PERIPH_BASE)
    #define DMA_DST_BASE (CYDEV_SRAM_BASE)

	/* Enable global interrupt */
	CYGlobalIntEnable; 
	
	/* Start isr connected to DMA nrq signal */
	ISR_1_Start();
	ISR_DMA_Done_Start();	
	//ISR_DMA_Done_Enable();
	//ISR_DMA_Done_ClearPending();

    /* DMA Initialization - 2 byte per trigger.Each burst transfer needs a new request. 
	 * Set upper source and destination address. */	
    DMA_1_Chan = DMA_1_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, 
                                 HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE));
    DMA_2_Chan = DMA_2_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, 
                                 HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE));

    /* Allocate TD */
    DMA_1_TD[0] = CyDmaTdAllocate();
	DMA_2_TD[0] = CyDmaTdAllocate();


    #if (defined(__C51__))
    /* In PSoC 3 TD swap should be enabled for endian swapping . 
	 * Destination address is incremented after each transaction and
 	 * Term out generated after the specified no. of bytes are transferred to memory
	 * Tranfer the specified number of samples and generate term out */	
    CyDmaTdSetConfiguration(DMA_TD[0], (2 * NO_OF_SAMPLES), DMA_TD[0], 
                            TD_SWAP_EN | DMA__TD_TERMOUT_EN | TD_INC_DST_ADR);
                            
    #else
    /* Destination address is incremented after each transaction and Term out generated after 
     * the specified no. of bytes are transferred to memory
	 * Tranfer the specified number of samples and generate term out */
	CyDmaTdSetConfiguration(DMA_1_TD[0], (2 * NO_OF_SAMPLES), DMA_1_TD[0], 
                            DMA_1__TD_TERMOUT_EN | TD_INC_DST_ADR);     
	 
    CyDmaTdSetConfiguration(DMA_2_TD[0], (2 * NO_OF_SAMPLES), DMA_2_TD[0], 
                            DMA_2__TD_TERMOUT_EN | TD_INC_DST_ADR);     
    #endif
    
    /* Set source and destination address */
    CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)ADC_SAR_1_SAR_WRK0_PTR), 
                            LO16((uint32)ADC_sample1));
   
	CyDmaTdSetAddress(DMA_2_TD[0], LO16((uint32)ADC_SAR_2_SAR_WRK0_PTR), 
                            LO16((uint32)ADC_sample2));
                           
    /* Set the intial TD for the channel */
    CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]);

    CyDmaChSetInitialTd(DMA_2_Chan, DMA_2_TD[0]);

	
/*	//start win7 multi_touch
	USBFS_Start(0x00, USBFS_5V_OPERATION); 
	
	while(!USBFS_bGetConfiguration());
	
	CyDelay(10000);
	
	handle_mouse1_report();
*/	
	//===begin cary●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●
	
	ADC_SAR_1_Start();
	ADC_SAR_2_Start();
	
	CyDmaChEnable(DMA_1_Chan, 1);
	CyDmaChEnable(DMA_2_Chan, 1);
	
    PWM_Start();
	PWM_Stop_flag = 0;
  for(;;){
	while(1)
	{
	    uint16  m=1,n=1;
	    uint16  dat1=500,dat2=500;
        uint16  Tar[1024]={0},Tar1[1024]={0};
	    // If DMA has finished the transfer 
		ADC_SAR_1_Start();
	    ADC_SAR_2_Start();
	
	    CyDmaChEnable(DMA_1_Chan, 1);
	    CyDmaChEnable(DMA_2_Chan, 1);
	
        PWM_Start();
	    PWM_Stop_flag = 0;
		
	 if(DMADone_flag1 == 1 || DMADone_flag2 == 1)
	 {
			//CyDelay(2);
			
		    PWM_Stop();
			
			// Disable the DMA channel 
			CyDmaChDisable(DMA_1_Chan);
			CyDmaChDisable(DMA_2_Chan);
			
			PWM_Stop_flag = 1;
						
			// Clear the Flag 
			DMADone_flag1 = 0;
			DMADone_flag2 = 0;
			
			
		//ADC_sample[13]=2048,ADC_sample[1012]=2048;
		//ADC_sample1[13]=2048,ADC_sample1[1012]=2048;	
		
	    for(loopCNT1=13;loopCNT1<1013;loopCNT1++)
        { 
		  if(dat1> ADC_sample1[loopCNT1])
          {dat1= ADC_sample1[loopCNT1];
           target_data=loopCNT1;
           }
		     else if(ADC_sample1[loopCNT1]>=500 && ADC_sample1[loopCNT1]<=2048)
		            target_data1=loopCNT1;
		  if(target_data1>target_data)
		     if(target_data!=Tar[m-1])
			   {Tar[m]=target_data;
			    m++;
				}
        }
		
		for(loopCNT2=13;loopCNT2<1013;loopCNT2++)
        { 
		  if(dat2> ADC_sample2[loopCNT2])
          {dat2= ADC_sample2[loopCNT2];
           target_data2=loopCNT2;
           }
		    else if(ADC_sample2[loopCNT1]>=500 && ADC_sample2[loopCNT1]<=2048)
		            target_data3=loopCNT1;
		  if(target_data3>target_data2)
		     if(target_data2!=Tar1[n-1])
			   {Tar1[n]=target_data2;
			    n++;
				}
        }
	  }
	}
	/*loopCNT1=1,loopCNT2=1;
	VALID_SAMPLE1=0,VALID_SAMPLE2=0;
    while(loopCNT1<=1024&&loopCNT2<=1024)
	{
	    
	    // If DMA has finished the transfer 
		
		if(DMADone_flag1==1||DMADone_flag2==1)
		{
			//CyDelay(2);
			
		    PWM_Stop();
			
			// Disable the DMA channel 
			CyDmaChDisable(DMA_1_Chan);
			CyDmaChDisable(DMA_2_Chan);
			
			PWM_Stop_flag = 1;
			
			// Clear the Flag 
			DMADone_flag1 = 0;
			DMADone_flag2 = 0;
			
            while(loopCNT1<=12&&loopCNT2<=12)
			    {
				  ADC_sample1[loopCNT1]=data;
				  ADC_sample2[loopCNT2]=data;
				  loopCNT1++,loopCNT2++;
				 }
		
            for( ;loopCNT1 < 1013&&loopCNT2<1013; loopCNT1++,loopCNT2++)
	           {
	   		       if(data-400 > ADC_sample1[loopCNT1])    // -20% error tolerance to clear noise
			          {
					    Array1[VALID_SAMPLE1]= loopCNT1;      
			            VALID_SAMPLE1++;
						}
	   		       if(data-400 > ADC_sample2[loopCNT2])    // -20% error tolerance to clear noise
			          {
					    Array2[VALID_SAMPLE2]= loopCNT2;      
			            VALID_SAMPLE2++;
					    }
	            }
			
			while((1013<=loopCNT1&&loopCNT1<=1024)&&(1013<=loopCNT2&&loopCNT2<=1024))
			     {
				   ADC_sample1[loopCNT1]=data;
				   loopCNT1++;
				   
				   ADC_sample2[loopCNT2]=data;
				   loopCNT2++;
				  }
		}
	}
	        for(i=0;Array1[i]!=0;i++)
			    {
				  S1+=Array1[i];
				 }
			  M1=0.09*(S1/i-12);
			
			for(j=0;Array2[j]!=0;j++)
			    {
				  S2+=Array2[j];
				 }
			  M2=0.09*(S2/j-12);
			  
			X1 = W* tan(M2*PI/180)/(tan(M1*PI/180)+tan(M2*PI/180));
			Y1 = X1* tan(M1*PI/180);
	*/		
		    
	      
       //ISR_DMA_Done_ClearPending();	 
	   //ISR_DMA_Done_Start();
	   //ISR_1_Start();	//by cary
	  
			CyDmaChEnable(DMA_1_Chan, 1);
			CyDmaChEnable(DMA_2_Chan, 1);
			PWM_Start();
   //disable win7 multi_touch in small paint
   /*for(;;)
     {
        Button_1_status = 0;
        Button_2_status = 0;
        contact_count = 0;   
        Count_ID_1 = 0;
        Count_ID_2 = 0; 
        x2 = 0;
        y2 = 0;
        
        // x1 : 0x0050 ~ 0x7AF
        // y1 : 0x02FF
        // x2 : 0x0080 ~ 0x070F
        // y2 : 0x07FF
        
        if (x1 > 0x07AF) 
        {
            x1 = 0x0050;
        }

        if (x1 == 0x03FF)
        {
            Button_1_status = 0;
            Count_ID_1 = 0x01;
            contact_count = 1;
            y1 = 0x04FF;       
        }        
        else if ((x1 == 0x0051) || (x1 == 0x03FE))
        {
            Button_1_status = 0x02;
            Count_ID_1 = 0x01;
            contact_count = 1;
            y1 = 0x04FF;         
        }
        else if ((0x0052 <= x1) && (x1 <= 0x03FD))
        {
            Button_1_status = 0x03;
            Count_ID_1 = 0x01;          
            contact_count = 1;
            y1 = 0x04FF;         
        }
        else if (x1 == 0x07AF)
        {
            Button_1_status = 0;
            Count_ID_1 = 0x01;
            contact_count = 1;
            y1 = 0x04FF;       
        }        
        else if ((x1 == 0x0450) || (x1 == 0x07AE))
        {
            Button_1_status = 0x02;
            Count_ID_1 = 0x01;
            contact_count = 1;
            y1 = 0x04FF;         
        }
        else if ((0x0451 <= x1) && (x1 <= 0x07AD))
        {
            Button_1_status = 0x03;
            Count_ID_1 = 0x01;          
            contact_count = 1;
            y1 = 0x04FF;         
        }        

        if(x1 == 0x02FF)
        {
            Button_2_status = 0;
            Count_ID_2 = 0x02;
            contact_count = 2;
            x2 = x1;
            y2 = 0x07FF;                
        }
        else if ((x1 == 0x0101) || (x1 == 0x02FE))
        {
            Button_2_status = 0x02;
            Count_ID_2 = 0x02;
            contact_count = 2;
            x2 = x1;
            y2 = 0x07FF;
        }
        else if ((0x0102 <= x1) && (x1 <= 0x02FD))
        {
            Button_2_status = 0x03;
            Count_ID_2 = 0x02;
            contact_count = 2;
            x2 = x1;
            y2 = 0x07FF;
        }     
        else if(x1 == 0x070F)
        {
            Button_2_status = 0;
            Count_ID_2 = 0x02;
            contact_count = 2;
            x2 = x1;
            y2 = 0x07FF;                
        }
        else if ((x1 == 0x0501) || (x1 == 0x070E))
        {
            Button_2_status = 0x02;
            Count_ID_2 = 0x02;
            contact_count = 2;
            x2 = x1;
            y2 = 0x07FF;
        }
        else if ((0x0502 <= x1) && (x1 <= 0x070D))
        {
            Button_2_status = 0x03;
            Count_ID_2 = 0x02;
            contact_count = 2;
            x2 = x1;
            y2 = 0x07FF;
        }                     
        
        x1 += 0x01;
                
	    move_x1_h  = HI8(x1);
	    move_x1_l  = LO8(x1);
	    move_y1_h  = HI8(y1);
	    move_y1_l  = LO8(y1);
	    move_x2_h  = HI8(x2);
	    move_x2_l  = LO8(x2);
	    move_y2_h  = HI8(y2);
	    move_y2_l  = LO8(y2);
	    
        handle_mouse_report();
     }*/
			
 }		
}       // If statement ends here 
		//==begin cary●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●●
		//No_of_Pulse = PWM_ReadPeriod();
		
		//Pulse_status = Status_Reg_1_Read();	//0: pulse is low  ; 1: pulse is high
		
		
			//CyDelayus(10);	//delay us
			//CyDelayms(10);	//delay ms
		
		
		
    /* for loop ends here */	   	   	   	   
	   
        
	/* Place your application code here. */


/* [] END OF FILE */
